package dev.peerat.backend.routes;

import static dev.peerat.framework.RequestType.POST;

import java.util.regex.Matcher;

import org.json.simple.JSONObject;

import dev.peerat.backend.bonus.extract.RouteDoc;
import dev.peerat.backend.model.PeerAtUser;
import dev.peerat.backend.repository.DatabaseRepository;
import dev.peerat.framework.Context;
import dev.peerat.framework.HttpReader;
import dev.peerat.framework.HttpWriter;
import dev.peerat.framework.Response;
import dev.peerat.framework.Route;
import dev.peerat.framework.Router;

public class Login implements Response {

	private DatabaseRepository databaseRepo;
	private Router<PeerAtUser> router;

	public Login(DatabaseRepository databaseRepo, Router<PeerAtUser> router) {
		this.databaseRepo = databaseRepo;
		this.router = router;
	}
	
	@RouteDoc(path = "/login", responseCode = 200, responseDescription = "L'utilisateur est inscrit")
	@RouteDoc(responseCode = 403, responseDescription = "L'utilisateur est connecté")
	@RouteDoc(responseCode = 400, responseDescription = "Aucune données fournie / données invalide")

	@Route(path = "^\\/login$", type = POST)
	public void exec(Matcher matcher, Context context, HttpReader reader, HttpWriter writer) throws Exception {
		if (context.getUser() != null) {
			context.response(403);
			return;
		}
		JSONObject informations = reader.readJson();
		if (informations != null) {
			String pseudo = (String) informations.get("pseudo");
			String password = (String) informations.get("passwd");
			int id;
			if ((id = databaseRepo.login(pseudo, password)) >= 0) {
				context.response(200,
						"Access-Control-Expose-Headers: Authorization",
						"Authorization: Bearer " + this.router.createAuthUser(new PeerAtUser(id)));
				return;
			}
		}
		context.response(400);
	}

}
